@@ -24,7 +24,6 @@
 #include "AmarokMimeData.h"
 #include "GlobalCollectionActions.h"
 #include "PopupDropperFactory.h"
-#include "SvgHandler.h"
 #include "browsers/CollectionSortFilterProxyModel.h"
 #include "browsers/CollectionTreeItemModel.h"
 #include "context/ContextView.h"
@@ -44,12 +43,11 @@
 #include "scripting/scriptengine/AmarokCollectionViewScript.h"
 
 #include <QAction>
-#include <QIcon>
-#include <QComboBox>
-#include <QMenu>
-
+#include <QApplication>
 #include <QContextMenuEvent>
 #include <QHash>
+#include <QIcon>
+#include <QMenu>
 #include <QMouseEvent>
 #include <QQueue>
 #include <QSortFilterProxyModel>
@@ -318,7 +316,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
     if( m_filterModel )
     {
         QModelIndexList tmp;
-        foreach( const QModelIndex &idx, indices )
+        for( const QModelIndex &idx : indices )
         {
             tmp.append( m_filterModel->mapToSource( idx ) );
         }
@@ -330,7 +328,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
         return;
 
     m_currentItems.clear();
-    foreach( const QModelIndex &index, indices )
+    for( const QModelIndex &index : indices )
     {
         if( index.isValid() && index.internalPointer() )
             m_currentItems.insert(
@@ -359,7 +357,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
         }
         actions.append( m_collapseAction );
     }
-    foreach( QAction *action, actions ) {
+    for( QAction *action : actions ) {
         menu.addAction( action );
     }
     menu.addSeparator();
@@ -367,7 +365,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
 
     QActionList albumActions = createCustomActions( indices );
     QMenu menuAlbum( i18n( "Album" )  );
-    foreach( QAction *action, albumActions )
+    for( QAction *action : albumActions )
     {
         if( !action->parent() )
             action->setParent( &menuAlbum );
@@ -387,7 +385,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
 
     QActionList collectionActions = createCollectionActions( indices );
     QMenu menuCollection( i18n( "Collection" ) );
-    foreach( QAction *action, collectionActions )
+    for( QAction *action : collectionActions )
     {
         if( !action->parent() )
             action->setParent( &menuCollection );
@@ -435,7 +433,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
             QAction *trashAction = new QAction( QIcon::fromTheme( QStringLiteral("user-trash") ),
                                                 i18n( "Move Tracks to Trash" ),
                                                 &menu );
-            trashAction->setProperty( "popupdropper_svg_id", "delete" );
+            trashAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
             // key shortcut is only for display purposes here, actual one is
             // determined by View in Model/View classes
             trashAction->setShortcut( Qt::Key_Delete );
@@ -446,10 +444,10 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
             QAction *deleteAction = new QAction( QIcon::fromTheme( QStringLiteral("remove-amarok") ),
                                                  i18n( "Delete Tracks" ),
                                                  &menu );
-            deleteAction->setProperty( "popupdropper_svg_id", "delete" );
+            deleteAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete") );
             // key shortcut is only for display purposes here, actual one is
             // determined by View in Model/View classes
-            deleteAction->setShortcut( Qt::SHIFT + Qt::Key_Delete );
+            deleteAction->setShortcut( Qt::SHIFT | Qt::Key_Delete );
             connect( deleteAction, &QAction::triggered, this, &CollectionTreeView::slotDeleteTracks );
             menu.addAction( deleteAction );
         }
@@ -458,7 +456,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
     // add extended actions
     menu.addSeparator();
     actions += createExtendedActions( indices );
-    foreach( QAction *action, actions ) {
+    for( QAction *action : actions ) {
         menu.addAction( action );
     }
     AmarokScript::AmarokCollectionViewScript::createScriptedActions( menu, indices );
@@ -469,7 +467,7 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
 void
 CollectionTreeView::mouseDoubleClickEvent( QMouseEvent *event )
 {
-    if( event->button() == Qt::MidButton )
+    if( event->button() == Qt::MiddleButton )
     {
         event->accept();
         return;
@@ -517,7 +515,7 @@ CollectionTreeView::mouseReleaseEvent( QMouseEvent *event )
         return;
     }
 
-    if( event->button() == Qt::MidButton )
+    if( event->button() == Qt::MiddleButton )
     {
         CollectionTreeItem *item = getItemFromIndex( index );
         playChildTracks( item, Playlist::OnMiddleClickOnSelectedItems );
@@ -558,13 +556,13 @@ CollectionTreeView::keyPressEvent( QKeyEvent *event )
     if( m_filterModel )
     {
         QModelIndexList tmp;
-        foreach( const QModelIndex &idx, indices )
+        for( const QModelIndex &idx : indices )
             tmp.append( m_filterModel->mapToSource( idx ) );
         indices = tmp;
     }
 
     m_currentItems.clear();
-    foreach( const QModelIndex &index, indices )
+    for( const QModelIndex &index : indices )
     {
         if( index.isValid() && index.internalPointer() )
         {
@@ -611,7 +609,7 @@ CollectionTreeView::dragEnterEvent( QDragEnterEvent *event )
     if( mimeData ) // drag from within Amarok
     {
         QSet<Collection *> srcCollections;
-        foreach( Meta::TrackPtr track, mimeData->tracks() )
+        for( Meta::TrackPtr track : mimeData->tracks() )
         {
             srcCollections.insert( track->collection() );
         }
@@ -666,7 +664,7 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
         if( m_filterModel )
         {
             QModelIndexList tmp;
-            foreach( const QModelIndex &idx, indices )
+            for( const QModelIndex &idx : indices )
             {
                 tmp.append( m_filterModel->mapToSource( idx ) );
             }
@@ -679,14 +677,14 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
         font.setPointSize( 16 );
         font.setBold( true );
 
-        foreach( QAction * action, actions )
+        for( QAction * action : actions )
             m_pd->addItem( The::popupDropperFactory()->createItem( action ) );
 
         m_currentCopyDestination = getCopyActions( indices );
         m_currentMoveDestination = getMoveActions( indices );
 
         m_currentItems.clear();
-        foreach( const QModelIndex &index, indices )
+        for( const QModelIndex &index : indices )
         {
             if( index.isValid() && index.internalPointer() )
             {
@@ -704,7 +702,7 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
         {
             morePud = The::popupDropperFactory()->createPopupDropper( nullptr, true );
 
-            foreach( QAction *action, actions )
+            for( QAction *action : actions )
                 morePud->addItem( The::popupDropperFactory()->createItem( action ) );
         }
         else
@@ -741,7 +739,7 @@ CollectionTreeView::selectionChanged( const QItemSelection &selected,
 
     QModelIndexList changedIndexes = indexes;
     changedIndexes << deselected.indexes();
-    foreach( const QModelIndex &index, changedIndexes )
+    for( const QModelIndex &index : changedIndexes )
         update( index );
 
     if( indexes.count() < 1 )
@@ -878,10 +876,13 @@ CollectionTreeView::copySelectedToLocalCollection()
     Collections::Collection *collection = nullptr;
     const QList<Collections::Collection*> collections = CollectionManager::instance()->collections().keys();
 
-    foreach( collection, collections )
+    for( const auto &c : collections )
     {
-        if ( collection->collectionId() == QLatin1String("localCollection") )
+        if ( c->collectionId() == QLatin1String("localCollection") )
+        {
+            collection = c;
             break;
+        }
     }
 
     if( !collection )
@@ -892,13 +893,13 @@ CollectionTreeView::copySelectedToLocalCollection()
     if( m_filterModel )
     {
         QModelIndexList tmp;
-        foreach( const QModelIndex &idx, indexes )
+        for( const QModelIndex &idx : indexes )
             tmp.append( m_filterModel->mapToSource( idx ) );
         indexes = tmp;
     }
 
     m_currentItems.clear();
-    foreach( const QModelIndex &index, indexes )
+    for( const QModelIndex &index : indexes )
     {
         if( index.isValid() && index.internalPointer() )
             m_currentItems.insert( static_cast<CollectionTreeItem *>( index.internalPointer() ) );
@@ -1087,7 +1088,7 @@ CollectionTreeView::createBasicActions( const QModelIndexList &indices )
         {
             m_appendAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ),
                                           i18n( "&Add to Playlist" ), this );
-            m_appendAction->setProperty( "popupdropper_svg_id", "append" );
+            m_appendAction->setProperty( "popupdropper_svg_id", QStringLiteral("append") );
             connect( m_appendAction, &QAction::triggered, this, &CollectionTreeView::slotAppendChildTracks );
         }
 
@@ -1098,7 +1099,7 @@ CollectionTreeView::createBasicActions( const QModelIndexList &indices )
             m_loadAction = new QAction(
                         i18nc( "Replace the currently loaded tracks with these",
                                "&Replace Playlist" ), this );
-            m_loadAction->setProperty( "popupdropper_svg_id", "load" );
+            m_loadAction->setProperty( "popupdropper_svg_id", QStringLiteral("load") );
             connect( m_loadAction, &QAction::triggered,
                      this, &CollectionTreeView::slotReplacePlaylistWithChildTracks );
         }
@@ -1128,7 +1129,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
             if( location->isOrganizable() )
             {
                 bool onlyOneCollection = true;
-                foreach( const QModelIndex &index, indices )
+                for( const QModelIndex &index : indices )
                 {
                     Q_UNUSED( index )
                     CollectionTreeItem *item = static_cast<CollectionTreeItem *>(
@@ -1147,7 +1148,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
                     {
                         m_organizeAction = new QAction( QIcon::fromTheme(QStringLiteral("folder-open") ),
                                     i18nc( "Organize Files", "Organize Files" ), this );
-                        m_organizeAction->setProperty( "popupdropper_svg_id", "organize" );
+                        m_organizeAction->setProperty( "popupdropper_svg_id", QStringLiteral("organize") );
                         connect( m_organizeAction, &QAction::triggered,
                                  this, &CollectionTreeView::slotOrganize );
                     }
@@ -1166,7 +1167,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
                         indices.first().internalPointer() );
 
             QActionList gActions = The::globalCollectionActions()->actionsFor( item->data() );
-            foreach( QAction *action, gActions )
+            for( QAction *action : gActions )
             {
                 if( action ) // Can become 0-pointer, see https://bugs.kde.org/show_bug.cgi?id=183250
                 {
@@ -1180,7 +1181,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
         {
             m_editAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ),
                                         i18n( "&Edit Track Details" ), this );
-            setProperty( "popupdropper_svg_id", "edit" );
+            setProperty( "popupdropper_svg_id", QStringLiteral("edit") );
             connect( m_editAction, &QAction::triggered, this, &CollectionTreeView::slotEditTracks );
         }
         actions.append( m_editAction );
@@ -1209,7 +1210,7 @@ CollectionTreeView::createCustomActions( const QModelIndexList &indices )
                 {
                     QActionList cActions = ac->actions();
 
-                    foreach( QAction *action, cActions )
+                    for( QAction *action : cActions )
                     {
                         Q_ASSERT( action );
                         actions.append( action );
@@ -1277,10 +1278,10 @@ CollectionTreeView::getCopyActions( const QModelIndexList &indices )
         }
         if( !writableCollections.isEmpty() )
         {
-            foreach( Collection *coll, writableCollections )
+            for( Collection *coll : writableCollections )
             {
                 QAction *action = new QAction( coll->icon(), coll->prettyName(), nullptr );
-                action->setProperty( "popupdropper_svg_id", "collection" );
+                action->setProperty( "popupdropper_svg_id", QStringLiteral("collection") );
                 connect( action, &QAction::triggered, this, &CollectionTreeView::slotCopyTracks );
 
                 currentCopyDestination.insert( action, coll );
@@ -1314,10 +1315,10 @@ CollectionTreeView::getMoveActions( const QModelIndexList &indices )
         {
             if( collection->isWritable() )
             {
-                foreach( Collection *coll, writableCollections )
+                for( Collection *coll : writableCollections )
                 {
                     QAction *action = new QAction( coll->icon(), coll->prettyName(), nullptr );
-                    action->setProperty( "popupdropper_svg_id", "collection" );
+                    action->setProperty( "popupdropper_svg_id", QStringLiteral("collection") );
                     connect( action, &QAction::triggered, this, &CollectionTreeView::slotMoveTracks );
                     currentMoveDestination.insert( action, coll );
                 }
@@ -1332,7 +1333,7 @@ bool CollectionTreeView::onlyOneCollection( const QModelIndexList &indices )
     if( !indices.isEmpty() )
     {
         Collection *collection = getCollection( indices.first() );
-        foreach( const QModelIndex &index, indices )
+        for( const QModelIndex &index : indices )
         {
             Collection *currentCollection = getCollection( index );
             if( collection != currentCollection )
@@ -1430,7 +1431,7 @@ QSet<CollectionTreeItem *>
 CollectionTreeView::cleanItemSet( const QSet<CollectionTreeItem *> &items )
 {
     QSet<CollectionTreeItem *> parents;
-    foreach( CollectionTreeItem *item, items )
+    for( CollectionTreeItem *item : items )
     {
         CollectionTreeItem *tmpItem = item;
         while( tmpItem )
@@ -1457,7 +1458,7 @@ CollectionTreeView::createMetaQueryFromItems( const QSet<CollectionTreeItem *> &
     QSet<CollectionTreeItem*> parents = cleanItems ? cleanItemSet( items ) : items;
 
     QList<Collections::QueryMaker *> queryMakers;
-    foreach( CollectionTreeItem *item, parents )
+    for( CollectionTreeItem *item : parents )
     {
         Collections::QueryMaker *qm = item->queryMaker();
         for( CollectionTreeItem *tmp = item; tmp; tmp = tmp->parent() )
