@@ -21,16 +21,13 @@
 #include "core-impl/collections/support/CollectionManager.h"
 #include "statsyncing/Config.h"
 
-#include <KConfigGroup>
 #include <KLocalizedString>
 
 #include <QDialogButtonBox>
-#include <QGridLayout>
 #include <QLabel>
 #include <QLineEdit>
 #include <QListWidget>
 #include <QPushButton>
-#include <QToolButton>
 #include <QVBoxLayout>
 
 ExcludedLabelsDialog::ExcludedLabelsDialog( StatSyncing::Config *config, QWidget *parent,
@@ -69,7 +66,7 @@ ExcludedLabelsDialog::ExcludedLabelsDialog( StatSyncing::Config *config, QWidget
 void
 ExcludedLabelsDialog::slowNewResultReady( const Meta::LabelList &labels )
 {
-    foreach( const Meta::LabelPtr &label, labels )
+    for( const Meta::LabelPtr &label : labels )
         addLabel( label->name() );
 }
 
@@ -84,7 +81,7 @@ void
 ExcludedLabelsDialog::slotSaveToConfig()
 {
     QSet<QString> excluded;
-    foreach( const QListWidgetItem *item, listWidget->selectedItems() )
+    for( const QListWidgetItem *item : listWidget->selectedItems() )
     {
         excluded.insert( item->text() );
     }
@@ -127,7 +124,7 @@ ExcludedLabelsDialog::addLabel( const QString &label, bool selected )
 void
 ExcludedLabelsDialog::addLabels( const QSet<QString> &labels, bool selected )
 {
-    foreach( const QString &label, labels )
+    for( const QString &label : labels )
     {
         addLabel( label, selected );
     }
