@@ -31,6 +31,7 @@
 #include <playlist/PlaylistController.h>
 
 #include <QMenu>
+#include <QRegularExpression>
 
 #include <KLocalizedString>
 
@@ -128,7 +129,7 @@ void AlbumsEngine::updateRecentlyAddedAlbums()
     qm->setQueryType( Collections::QueryMaker::Album );
     qm->excludeFilter( Meta::valAlbum, QString(), true, true );
     qm->orderBy( Meta::valCreateDate, true );
-    qm->limitMaxResultSize( Amarok::config("Albums Applet").readEntry("RecentlyAdded", 5) );
+    qm->limitMaxResultSize( Amarok::config(QStringLiteral("Albums Applet")).readEntry("RecentlyAdded", 5) );
 
     connect( qm, &Collections::QueryMaker::newAlbumsReady,
              this, &AlbumsEngine::resultReady, Qt::QueuedConnection );
@@ -211,12 +212,12 @@ void AlbumsEngine::resultReady( const Meta::AlbumList &albums )
                     discItem = new QStandardItem( i18n("Disc %1", item->track()->discNumber()) );
                     albumItem->setChild( childRow++, discItem );
                     int discChildRow = 0;
-                    foreach( TrackItem *trackItem, items )
+                    for( TrackItem *trackItem : items )
                         discItem->setChild( discChildRow++, trackItem );
                 }
                 else
                 {
-                    foreach( TrackItem *trackItem, items )
+                    for( TrackItem *trackItem : items )
                         albumItem->setChild( childRow++, trackItem );
                 }
             }
@@ -229,15 +230,15 @@ void AlbumsEngine::resultReady( const Meta::AlbumList &albums )
 
 QString AlbumsEngine::filterPattern() const
 {
-    return m_proxyModel->filterRegExp().pattern();
+    return m_proxyModel->filterRegularExpression().pattern();
 }
 
 void AlbumsEngine::setFilterPattern( const QString &pattern )
 {
-    if( m_proxyModel->filterRegExp().pattern() == pattern )
+    if( m_proxyModel->filterRegularExpression().pattern() == pattern )
         return;
 
-    m_proxyModel->setFilterRegExp( QRegExp(pattern, Qt::CaseInsensitive) );
+    m_proxyModel->setFilterRegularExpression( QRegularExpression(pattern, QRegularExpression::CaseInsensitiveOption) );
     Q_EMIT filterPatternChanged();
 }
 
@@ -281,10 +282,10 @@ void AlbumsEngine::showContextMenu( const QModelIndexList &indexes, const QModel
         return;
 
     QMenu menu;
-    QAction *appendAction = new QAction( QIcon::fromTheme( "media-track-add-amarok" ), i18n( "&Add to Playlist" ), &menu );
-    QAction *loadAction   = new QAction( QIcon::fromTheme( "folder-open" ), i18nc( "Replace the currently loaded tracks with these", "&Replace Playlist" ), &menu );
-    QAction *queueAction  = new QAction( QIcon::fromTheme( "media-track-queue-amarok" ), i18n( "&Queue" ), &menu );
-    QAction *editAction   = new QAction( QIcon::fromTheme( "media-track-edit-amarok" ), i18n( "Edit Track Details" ), &menu );
+    QAction *appendAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ), i18n( "&Add to Playlist" ), &menu );
+    QAction *loadAction   = new QAction( QIcon::fromTheme( QStringLiteral("folder-open") ), i18nc( "Replace the currently loaded tracks with these", "&Replace Playlist" ), &menu );
+    QAction *queueAction  = new QAction( QIcon::fromTheme( QStringLiteral("media-track-queue-amarok") ), i18n( "&Queue" ), &menu );
+    QAction *editAction   = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ), i18n( "Edit Track Details" ), &menu );
 
     menu.addAction( appendAction );
     menu.addAction( loadAction );
@@ -308,14 +309,14 @@ void AlbumsEngine::showContextMenu( const QModelIndexList &indexes, const QModel
             if( !actions.isEmpty() )
             {
                 // ensure that the actions are cleaned up afterwards
-                foreach( QAction *action, actions )
+                for( QAction *action : actions )
                 {
                     if( !action->parent() )
                         action->setParent( &menuCover );
                 }
 
                 menuCover.addActions( actions );
-                menuCover.setIcon( QIcon::fromTheme( "filename-album-amarok" ) );
+                menuCover.setIcon( QIcon::fromTheme( QStringLiteral("filename-album-amarok") ) );
                 menu.addMenu( &menuCover );
             }
         }
@@ -329,7 +330,7 @@ QString AlbumsEngine::getSelectedUrlList(const QModelIndexList &indexes) const
     QString urlList;
     for(const Meta::TrackPtr &t : list)
     {
-        urlList+=t->playableUrl().toString()+"\n";
+        urlList += t->playableUrl().toString() + QStringLiteral("\n");
     }
     return urlList;
 }
