@@ -32,12 +32,13 @@
 #include <KIO/DeleteJob>
 #include "kjob.h"
 #include <ThreadWeaver/ThreadWeaver>
-#include <QUrl>
 
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QString>
 #include <QStringList>
 #include <QTextStream>
+#include <QUrl>
 
 using namespace Meta;
 
@@ -108,46 +109,46 @@ MtpHandler::isWritable() const
 void
 MtpHandler::init()
 {
-    mtpFileTypes[LIBMTP_FILETYPE_WAV] = "wav";
-    mtpFileTypes[LIBMTP_FILETYPE_MP3] = "mp3";
-    mtpFileTypes[LIBMTP_FILETYPE_WMA] = "wma";
-    mtpFileTypes[LIBMTP_FILETYPE_OGG] = "ogg";
-    mtpFileTypes[LIBMTP_FILETYPE_AUDIBLE] = "aa";
-    mtpFileTypes[LIBMTP_FILETYPE_MP4] = "mp4";
-    mtpFileTypes[LIBMTP_FILETYPE_UNDEF_AUDIO] = "undef-audio";
-    mtpFileTypes[LIBMTP_FILETYPE_WMV] = "wmv";
-    mtpFileTypes[LIBMTP_FILETYPE_AVI] = "avi";
-    mtpFileTypes[LIBMTP_FILETYPE_MPEG] = "mpg";
-    mtpFileTypes[LIBMTP_FILETYPE_ASF] = "asf";
-    mtpFileTypes[LIBMTP_FILETYPE_QT] = "mov";
-    mtpFileTypes[LIBMTP_FILETYPE_UNDEF_VIDEO] = "undef-video";
-    mtpFileTypes[LIBMTP_FILETYPE_JPEG] = "jpg";
-    mtpFileTypes[LIBMTP_FILETYPE_JFIF] = "jfif";
-    mtpFileTypes[LIBMTP_FILETYPE_TIFF] = "tiff";
-    mtpFileTypes[LIBMTP_FILETYPE_BMP] = "bmp";
-    mtpFileTypes[LIBMTP_FILETYPE_GIF] = "gif";
-    mtpFileTypes[LIBMTP_FILETYPE_PICT] = "pict";
-    mtpFileTypes[LIBMTP_FILETYPE_PNG] = "png";
-    mtpFileTypes[LIBMTP_FILETYPE_VCALENDAR1] = "vcs";
-    mtpFileTypes[LIBMTP_FILETYPE_VCALENDAR2] = "vcs";
-    mtpFileTypes[LIBMTP_FILETYPE_VCARD2] = "vcf";
-    mtpFileTypes[LIBMTP_FILETYPE_VCARD3] = "vcf";
-    mtpFileTypes[LIBMTP_FILETYPE_WINDOWSIMAGEFORMAT] = "wim";
-    mtpFileTypes[LIBMTP_FILETYPE_WINEXEC] = "exe";
-    mtpFileTypes[LIBMTP_FILETYPE_TEXT] = "txt";
-    mtpFileTypes[LIBMTP_FILETYPE_HTML] = "html";
-    mtpFileTypes[LIBMTP_FILETYPE_AAC] = "aac";
-    mtpFileTypes[LIBMTP_FILETYPE_FLAC] = "flac";
-    mtpFileTypes[LIBMTP_FILETYPE_MP2] = "mp3";
-    mtpFileTypes[LIBMTP_FILETYPE_M4A] = "m4a";
-    mtpFileTypes[LIBMTP_FILETYPE_DOC] = "doc";
-    mtpFileTypes[LIBMTP_FILETYPE_XML] = "xml";
-    mtpFileTypes[LIBMTP_FILETYPE_XLS] = "xls";
-    mtpFileTypes[LIBMTP_FILETYPE_PPT] = "ppt";
-    mtpFileTypes[LIBMTP_FILETYPE_MHT] = "mht";
-    mtpFileTypes[LIBMTP_FILETYPE_JP2] = "jpg";
-    mtpFileTypes[LIBMTP_FILETYPE_JPX] = "jpx";
-    mtpFileTypes[LIBMTP_FILETYPE_UNKNOWN] = "unknown";
+    mtpFileTypes[LIBMTP_FILETYPE_WAV] = QStringLiteral("wav");
+    mtpFileTypes[LIBMTP_FILETYPE_MP3] = QStringLiteral("mp3");
+    mtpFileTypes[LIBMTP_FILETYPE_WMA] = QStringLiteral("wma");
+    mtpFileTypes[LIBMTP_FILETYPE_OGG] = QStringLiteral("ogg");
+    mtpFileTypes[LIBMTP_FILETYPE_AUDIBLE] = QStringLiteral("aa");
+    mtpFileTypes[LIBMTP_FILETYPE_MP4] = QStringLiteral("mp4");
+    mtpFileTypes[LIBMTP_FILETYPE_UNDEF_AUDIO] = QStringLiteral("undef-audio");
+    mtpFileTypes[LIBMTP_FILETYPE_WMV] = QStringLiteral("wmv");
+    mtpFileTypes[LIBMTP_FILETYPE_AVI] = QStringLiteral("avi");
+    mtpFileTypes[LIBMTP_FILETYPE_MPEG] = QStringLiteral("mpg");
+    mtpFileTypes[LIBMTP_FILETYPE_ASF] = QStringLiteral("asf");
+    mtpFileTypes[LIBMTP_FILETYPE_QT] = QStringLiteral("mov");
+    mtpFileTypes[LIBMTP_FILETYPE_UNDEF_VIDEO] = QStringLiteral("undef-video");
+    mtpFileTypes[LIBMTP_FILETYPE_JPEG] = QStringLiteral("jpg");
+    mtpFileTypes[LIBMTP_FILETYPE_JFIF] = QStringLiteral("jfif");
+    mtpFileTypes[LIBMTP_FILETYPE_TIFF] = QStringLiteral("tiff");
+    mtpFileTypes[LIBMTP_FILETYPE_BMP] = QStringLiteral("bmp");
+    mtpFileTypes[LIBMTP_FILETYPE_GIF] = QStringLiteral("gif");
+    mtpFileTypes[LIBMTP_FILETYPE_PICT] = QStringLiteral("pict");
+    mtpFileTypes[LIBMTP_FILETYPE_PNG] = QStringLiteral("png");
+    mtpFileTypes[LIBMTP_FILETYPE_VCALENDAR1] = QStringLiteral("vcs");
+    mtpFileTypes[LIBMTP_FILETYPE_VCALENDAR2] = QStringLiteral("vcs");
+    mtpFileTypes[LIBMTP_FILETYPE_VCARD2] = QStringLiteral("vcf");
+    mtpFileTypes[LIBMTP_FILETYPE_VCARD3] = QStringLiteral("vcf");
+    mtpFileTypes[LIBMTP_FILETYPE_WINDOWSIMAGEFORMAT] = QStringLiteral("wim");
+    mtpFileTypes[LIBMTP_FILETYPE_WINEXEC] = QStringLiteral("exe");
+    mtpFileTypes[LIBMTP_FILETYPE_TEXT] = QStringLiteral("txt");
+    mtpFileTypes[LIBMTP_FILETYPE_HTML] = QStringLiteral("html");
+    mtpFileTypes[LIBMTP_FILETYPE_AAC] = QStringLiteral("aac");
+    mtpFileTypes[LIBMTP_FILETYPE_FLAC] = QStringLiteral("flac");
+    mtpFileTypes[LIBMTP_FILETYPE_MP2] = QStringLiteral("mp3");
+    mtpFileTypes[LIBMTP_FILETYPE_M4A] = QStringLiteral("m4a");
+    mtpFileTypes[LIBMTP_FILETYPE_DOC] = QStringLiteral("doc");
+    mtpFileTypes[LIBMTP_FILETYPE_XML] = QStringLiteral("xml");
+    mtpFileTypes[LIBMTP_FILETYPE_XLS] = QStringLiteral("xls");
+    mtpFileTypes[LIBMTP_FILETYPE_PPT] = QStringLiteral("ppt");
+    mtpFileTypes[LIBMTP_FILETYPE_MHT] = QStringLiteral("mht");
+    mtpFileTypes[LIBMTP_FILETYPE_JP2] = QStringLiteral("jpg");
+    mtpFileTypes[LIBMTP_FILETYPE_JPX] = QStringLiteral("jpx");
+    mtpFileTypes[LIBMTP_FILETYPE_UNKNOWN] = QStringLiteral("unknown");
 
     QString genericError = i18n( "Could not connect to MTP Device" );
 
@@ -296,7 +297,7 @@ MtpHandler::getDeviceInfo()
         m_capacity = m_device->storage->MaxCapacity;
     }
 
-    QString modelname = QString( LIBMTP_Get_Modelname( m_device ) );
+    QString modelname = QLatin1String( LIBMTP_Get_Modelname( m_device ) );
 
     // NOTE: on next libmtp bump, may reintroduce owner name
     // for now it doesn't work as expected
@@ -305,7 +306,7 @@ MtpHandler::getDeviceInfo()
     m_name = modelname;
     if(! ownername.isEmpty() )
         if( modelname != ownername )
-            m_name += " (" + ownername + ')';
+            m_name += " (" + ownername + QLatin1Char(')');
 
     else
         m_name += " (No Owner Name)";
@@ -332,12 +333,12 @@ MtpHandler::getDeviceInfo()
         }
     }
     // find supported image types (for album art).
-    if ( m_supportedFiles.indexOf( "jpg" ) )
-        m_format = "JPEG";
-    else if ( m_supportedFiles.indexOf( "png" ) )
-        m_format = "PNG";
-    else if ( m_supportedFiles.indexOf( "gif" ) )
-        m_format = "GIF";
+    if ( m_supportedFiles.indexOf( QStringLiteral("jpg") ) )
+        m_format = QStringLiteral("JPEG");
+    else if ( m_supportedFiles.indexOf( QStringLiteral("png") ) )
+        m_format = QStringLiteral("PNG");
+    else if ( m_supportedFiles.indexOf( QStringLiteral("gif") ) )
+        m_format = QStringLiteral("GIF");
     free( filetypes );
 }
 
@@ -377,7 +378,7 @@ MtpHandler::getCopyableUrls( const Meta::TrackList &tracks )
 
     QString genericError = i18n( "Could not copy track from device." );
 
-    foreach( Meta::TrackPtr trackptr,  tracks )
+    for( Meta::TrackPtr trackptr :  tracks )
     {
         Meta::MediaDeviceTrackPtr track = Meta::MediaDeviceTrackPtr::dynamicCast( trackptr );
         if( !track )
@@ -446,17 +447,17 @@ MtpHandler::checkFolderStructure( const Meta::TrackPtr track, bool create )
         if (( *it ).isEmpty() )
             continue;
         // substitute %a , %b , %g
-        ( *it ).replace( QRegExp( "%a" ), artistName )
-        .replace( QRegExp( "%b" ), albumName )
-        .replace( QRegExp( "%g" ), genreName );
+        ( *it ).replace( QRegularExpression( QStringLiteral("%a") ), artistName )
+        .replace( QRegularExpression( QStringLiteral("%b") ), albumName )
+        .replace( QRegularExpression( QStringLiteral("%g") ), genreName );
         // check if it exists
-        uint32_t check_folder = subfolderNameToID(( *it ).toUtf8(), m_folders, parent_id );
+        uint32_t check_folder = subfolderNameToID(( *it ).toUtf8().constData(), m_folders, parent_id );
         // create if not exists (if requested)
         if ( check_folder == 0 )
         {
             if ( create )
             {
-                check_folder = createFolder(( *it ).toUtf8() , parent_id );
+                check_folder = createFolder(( *it ).toUtf8().constData() , parent_id );
                 if ( check_folder == 0 )
                 {
                     return 0;
@@ -467,7 +468,7 @@ MtpHandler::checkFolderStructure( const Meta::TrackPtr track, bool create )
                 return 0;
             }
         }
-        completePath += ( *it ).toUtf8() + '/';
+        completePath += ( *it ) + QLatin1Char('/');
         // set new parent
         parent_id = check_folder;
     }
@@ -488,7 +489,7 @@ MtpHandler::getDefaultParentId( void )
     // Otherwise look for a folder called "Music"
     else if ( m_folders != nullptr )
     {
-        parent_id = folderNameToID( qstrdup( QString( "Music" ).toUtf8() ), m_folders );
+        parent_id = folderNameToID( qstrdup( QStringLiteral( "Music" ).toUtf8().constData() ), m_folders );
         if ( !parent_id )
         {
             debug() << "Parent folder could not be found. Going to use top level.";
@@ -616,7 +617,7 @@ MtpHandler::privateDeleteTrackFromDevice( const Meta::MtpTrackPtr &track )
 int
 MtpHandler::getTrackToFile( const uint32_t id, const QString & filename )
 {
-    return LIBMTP_Get_Track_To_File( m_device, id, filename.toUtf8(), nullptr, nullptr );
+    return LIBMTP_Get_Track_To_File( m_device, id, filename.toUtf8().constData(), nullptr, nullptr );
 }
 
 int
@@ -694,7 +695,7 @@ MtpHandler::libCopyTrack( const Meta::TrackPtr &srcTrack, Meta::MediaDeviceTrack
 
 
 
-    int ret = LIBMTP_Send_Track_From_File( m_device, qstrdup( srcTrack->playableUrl().path().toUtf8() ), m_mtpTrackHash.value( destTrack ),
+    int ret = LIBMTP_Send_Track_From_File( m_device, qstrdup( srcTrack->playableUrl().path().toUtf8().constData() ), m_mtpTrackHash.value( destTrack ),
                                            nullptr, nullptr );
 
     debug() << "sent";
@@ -858,13 +859,13 @@ MtpHandler::libSavePlaylist( const Playlists::MediaDevicePlaylistPtr &playlist,
     // Make new playlist
 
     LIBMTP_playlist_t *metadata = LIBMTP_new_playlist_t();
-    metadata->name = qstrdup( name.toUtf8() );
+    metadata->name = qstrdup( name.toUtf8().constData() );
     const int trackCount = tracklist.count();
     if( trackCount > 0 )
     {
         uint32_t *tracks = ( uint32_t* )malloc( sizeof( uint32_t ) * trackCount );
         uint32_t i = 0;
-        foreach( Meta::TrackPtr trk, tracklist )
+        for( Meta::TrackPtr trk : tracklist )
         {
             if( !trk ) // playlists might contain invalid tracks. see BUG: 297816
                 continue;
@@ -996,7 +997,7 @@ MtpHandler::libGetGenre( const Meta::MediaDeviceTrackPtr &track )
 int
 MtpHandler::libGetYear( const Meta::MediaDeviceTrackPtr &track )
 {
-    return QString::fromUtf8( m_mtpTrackHash.value( track )->date ).midRef( 0, 4 ).toUInt();
+    return QString::fromUtf8( m_mtpTrackHash.value( track )->date ).left( 4 ).toUInt();
 }
 
 qint64
@@ -1111,19 +1112,19 @@ MtpHandler::usedCapacity() const
 void
 MtpHandler::libSetTitle( Meta::MediaDeviceTrackPtr& track, const QString& title )
 {
-    m_mtpTrackHash.value( track )->title = ( title.isEmpty() ? qstrdup( "" ) : qstrdup( title.toUtf8() ) );
+    m_mtpTrackHash.value( track )->title = ( title.isEmpty() ? qstrdup( "" ) : qstrdup( title.toUtf8().constData() ) );
     debug() << "Set to: " << m_mtpTrackHash.value( track )->title;
 }
 void
 MtpHandler::libSetAlbum( Meta::MediaDeviceTrackPtr &track, const QString& album )
 {
-    m_mtpTrackHash.value( track )->album = ( album.isEmpty() ? qstrdup( "" ) : qstrdup( album.toUtf8() ) );
+    m_mtpTrackHash.value( track )->album = ( album.isEmpty() ? qstrdup( "" ) : qstrdup( album.toUtf8().constData() ) );
     debug() << "Set to: " << m_mtpTrackHash.value( track )->album;
 }
 void
 MtpHandler::libSetArtist( Meta::MediaDeviceTrackPtr &track, const QString& artist )
 {
-    m_mtpTrackHash.value( track )->artist = ( artist.isEmpty() ? qstrdup( "" ) : qstrdup( artist.toUtf8() ) );
+    m_mtpTrackHash.value( track )->artist = ( artist.isEmpty() ? qstrdup( "" ) : qstrdup( artist.toUtf8().constData() ) );
     debug() << "Set to: " << m_mtpTrackHash.value( track )->artist;
 }
 
@@ -1138,13 +1139,13 @@ MtpHandler::libSetAlbumArtist( MediaDeviceTrackPtr &track, const QString &albumA
 void
 MtpHandler::libSetComposer( Meta::MediaDeviceTrackPtr &track, const QString& composer )
 {
-    m_mtpTrackHash.value( track )->composer = ( composer.isEmpty() ? qstrdup( "" ) : qstrdup( composer.toUtf8() ) );
+    m_mtpTrackHash.value( track )->composer = ( composer.isEmpty() ? qstrdup( "" ) : qstrdup( composer.toUtf8().constData() ) );
     debug() << "Set to: " << m_mtpTrackHash.value( track )->composer;
 }
 void
 MtpHandler::libSetGenre( Meta::MediaDeviceTrackPtr &track, const QString& genre )
 {
-    m_mtpTrackHash.value( track )->genre = ( genre.isEmpty() ? qstrdup( "" ) : qstrdup( genre.toUtf8() ) );
+    m_mtpTrackHash.value( track )->genre = ( genre.isEmpty() ? qstrdup( "" ) : qstrdup( genre.toUtf8().constData() ) );
     debug() << "Set to: " << m_mtpTrackHash.value( track )->genre;
 }
 void
@@ -1154,7 +1155,7 @@ MtpHandler::libSetYear( Meta::MediaDeviceTrackPtr &track, const QString& year )
     {
         QString date;
         QTextStream( &date ) << year.toInt() << "0101T0000.0";
-        m_mtpTrackHash.value( track )->date = qstrdup( date.toUtf8() );
+        m_mtpTrackHash.value( track )->date = qstrdup( date.toUtf8().constData() );
     }
     else
         m_mtpTrackHash.value( track )->date = qstrdup( "00010101T0000.0" );
@@ -1226,19 +1227,19 @@ void
 MtpHandler::libSetType( Meta::MediaDeviceTrackPtr &track, const QString& type )
 {
     debug() << "filetype : " << type;
-    if ( type == "mp3" )
+    if ( type == QStringLiteral("mp3") )
     {
         m_mtpTrackHash.value( track )->filetype = LIBMTP_FILETYPE_MP3;
     }
-    else if ( type == "ogg" )
+    else if ( type == QStringLiteral("ogg") )
     {
         m_mtpTrackHash.value( track )->filetype = LIBMTP_FILETYPE_OGG;
     }
-    else if ( type == "wma" )
+    else if ( type == QStringLiteral("wma") )
     {
         m_mtpTrackHash.value( track )->filetype = LIBMTP_FILETYPE_WMA;
     }
-    else if ( type == "mp4" )
+    else if ( type == QStringLiteral("mp4") )
     {
         m_mtpTrackHash.value( track )->filetype = LIBMTP_FILETYPE_MP4;
     }
@@ -1276,7 +1277,7 @@ void
 MtpHandler::libSetPlayableUrl( Meta::MediaDeviceTrackPtr &destTrack, const Meta::TrackPtr &srcTrack )
 {
     if( !srcTrack->playableUrl().fileName().isEmpty() )
-        m_mtpTrackHash.value( destTrack )->filename = qstrdup( srcTrack->playableUrl().fileName().toUtf8() );
+        m_mtpTrackHash.value( destTrack )->filename = qstrdup( srcTrack->playableUrl().fileName().toUtf8().constData() );
 }
 
 void
@@ -1325,7 +1326,7 @@ QString
 MtpHandler::setTempFile( Meta::MediaDeviceTrackPtr &track, const QString &format )
 {
     m_cachedTracks[ track ] = new QTemporaryFile();
-    m_cachedTracks.value( track )->setFileTemplate( QDir::tempPath() +  "/XXXXXX." + format ); // set suffix based on info from libmtp
+    m_cachedTracks.value( track )->setFileTemplate( QDir::tempPath() + QStringLiteral("/XXXXXX.") + format ); // set suffix based on info from libmtp
     if (!m_cachedTracks.value( track )->open())
         return QString();
 
