@@ -19,8 +19,8 @@
 #include "core/collections/CollectionLocation.h"
 #include "core/meta/Meta.h"
 
-Collections::CollectionFactory::CollectionFactory( QObject *parent, const QVariantList &args )
-    : Plugins::PluginFactory( parent, args )
+Collections::CollectionFactory::CollectionFactory()
+    : Plugins::PluginFactory()
 {
 }
 
@@ -38,14 +38,14 @@ Collections::TrackProvider::~TrackProvider()
 }
 
 bool
-Collections::TrackProvider::possiblyContainsTrack( const KUrl &url ) const
+Collections::TrackProvider::possiblyContainsTrack( const QUrl &url ) const
 {
     Q_UNUSED( url )
     return false;
 }
 
 Meta::TrackPtr
-Collections::TrackProvider::trackForUrl( const KUrl &url )
+Collections::TrackProvider::trackForUrl( const QUrl &url )
 {
     Q_UNUSED( url )
     return Meta::TrackPtr();
@@ -91,4 +91,3 @@ Collections::Collection::isOrganizable() const
     return organizable;
 }
 
-#include "Collection.moc"
