@@ -27,7 +27,9 @@
 #include "core/support/Debug.h"
 
 #include <QImage>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkConfigurationManager>
+#endif
 
 #include <KLocalizedString>
 
@@ -202,9 +204,11 @@ Track::isPlayable() const
 QString
 Track::networkNotPlayableReason() const
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QNetworkConfigurationManager mgr;
     if( !mgr.isOnline() )
         return i18n( "No network connection" );
+#endif
 
     return QString();
 }
@@ -272,18 +276,16 @@ Meta::Artist::sortableName() const
     if( !m_sortableName.isEmpty() )
         return m_sortableName;
 
-    const QString &n = name();
+    const QString n = name();
     if( n.startsWith( QLatin1String("the "), Qt::CaseInsensitive ) )
     {
-        QStringRef article = n.leftRef( 3 );
-        QStringRef subject = n.midRef( 4 );
-        m_sortableName = QStringLiteral( "%1, %2" ).arg( subject.toString(), article.toString() );
+        // n.left( 3 ) = article, n.mid( 4 ) = subject
+        m_sortableName = QStringLiteral( "%1, %2" ).arg( n.mid( 4 ), n.left( 3 ) );
     }
     else if( n.startsWith( QLatin1String("dj "), Qt::CaseInsensitive ) )
     {
-        QStringRef article = n.leftRef( 2 );
-        QStringRef subject = n.midRef( 3 );
-        m_sortableName = QStringLiteral( "%1, %2" ).arg( subject.toString(), article.toString() );
+        // n.left( 2 ) = article, n.mid( 3 ) = subject
+        m_sortableName = QStringLiteral( "%1, %2" ).arg( n.mid( 3 ), n.left( 2 ) );
     }
     else
         m_sortableName = n;
