@@ -30,13 +30,12 @@
 #include "widgets/AlbumBreadcrumbWidget.h"
 #include "widgets/PixmapViewer.h"
 
+#include <QActionGroup>
 #include <QCloseEvent>
 #include <QDir>
 #include <QFileDialog>
 #include <QFontDatabase>
 #include <QFormLayout>
-#include <QGridLayout>
-#include <QHeaderView>
 #include <QLineEdit>
 #include <QListWidget>
 #include <QMenu>
@@ -106,7 +105,7 @@ CoverFoundDialog::CoverFoundDialog( const CoverFetchUnit::Ptr &unit,
     {
         const QString &name = m_album->albumArtist()->name();
         completionNames << name;
-        firstRunQuery += ' ' + name;
+        firstRunQuery += QLatin1Char(' ') + name;
     }
     m_query = firstRunQuery;
     m_album->setSuppressImageAutoFetch( true );
@@ -123,9 +122,9 @@ CoverFoundDialog::CoverFoundDialog( const CoverFetchUnit::Ptr &unit,
     m_search->completionObject()->setItems( completionNames );
     m_search->insertItem( 0, KStandardGuiItem::find().icon(), QString() );
     m_search->insertSeparator( 1 );
-    m_search->insertItem( 2, QIcon::fromTheme("filename-album-amarok"), m_album->name() );
+    m_search->insertItem( 2, QIcon::fromTheme(QStringLiteral("filename-album-amarok")), m_album->name() );
     if( m_album->hasAlbumArtist() )
-        m_search->insertItem( 3, QIcon::fromTheme("filename-artist-amarok"), m_album->albumArtist()->name() );
+        m_search->insertItem( 3, QIcon::fromTheme(QStringLiteral("filename-artist-amarok")), m_album->albumArtist()->name() );
 
     auto findItem = KStandardGuiItem::find();
     m_searchButton = new QPushButton( findItem.icon(), findItem.text(), searchBox );
@@ -137,7 +136,8 @@ CoverFoundDialog::CoverFoundDialog( const CoverFetchUnit::Ptr &unit,
     QAction *lastFmAct = new QAction( i18n( "Last.fm" ), sourceMenu );
     QAction *googleAct = new QAction( i18n( "Google" ), sourceMenu );
     QAction *discogsAct = new QAction( i18n( "Discogs" ), sourceMenu );
-    // TODO: currently broken, re-enable after adjusting to current API/returned doc
+    // TODO: currently broken, re-enable after adjusting to current API/returned doc.
+    // Also pending RegExp porting in CoverFetchArtPayload::prepareGoogleUrls()
     googleAct->setEnabled( false );
     // TODO: currently broken, re-enable after adjusting to current API/returned doc
     discogsAct->setEnabled( false );
@@ -207,16 +207,16 @@ CoverFoundDialog::CoverFoundDialog( const CoverFetchUnit::Ptr &unit,
     splitter->addWidget( vbox );
 //     setMainWidget( splitter );
 
-    const KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    const KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     const QString source = config.readEntry( "Interactive Image Source", "LastFm" );
     m_sortEnabled = config.readEntry( "Sort by Size", false );
     m_sortAction->setChecked( m_sortEnabled );
     m_isSorted = m_sortEnabled;
     KWindowConfig::restoreWindowSize( windowHandle(), config ); // call this after setMainWidget()
 
-    if( source == "LastFm" )
+    if( source == QStringLiteral("LastFm") )
         lastFmAct->setChecked( true );
-    else if( source == "Discogs" )
+    else if( source == QStringLiteral("Discogs") )
         discogsAct->setChecked( true );
     else
         googleAct->setChecked( true );
@@ -240,15 +240,15 @@ CoverFoundDialog::~CoverFoundDialog()
 {
     m_album->setSuppressImageAutoFetch( false );
 
-    const QList<QListWidgetItem*> &viewItems = m_view->findItems( QChar('*'), Qt::MatchWildcard );
+    const QList<QListWidgetItem*> &viewItems = m_view->findItems( QStringLiteral("*"), Qt::MatchWildcard );
     qDeleteAll( viewItems );
     delete m_dialog.data();
 }
 
 void CoverFoundDialog::hideEvent( QHideEvent *event )
 {
-    KConfigGroup config = Amarok::config( "Cover Fetcher" );
-    config.writeEntry( "geometry", saveGeometry() );
+    KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
+    config.writeEntry( QStringLiteral("geometry"), saveGeometry() );
     event->accept();
 }
 
@@ -270,11 +270,11 @@ void CoverFoundDialog::addToView( CoverFoundItem *item )
 {
     const CoverFetch::Metadata &metadata = item->metadata();
 
-    if( m_sortEnabled && metadata.contains( "width" ) && metadata.contains( "height" ) )
+    if( m_sortEnabled && metadata.contains( QStringLiteral("width") ) && metadata.contains( QStringLiteral("height") ) )
     {
         if( m_isSorted )
         {
-            const int size = metadata.value( "width" ).toInt() * metadata.value( "height" ).toInt();
+            const int size = metadata.value( QStringLiteral("width") ).toInt() * metadata.value( QStringLiteral("height") ).toInt();
             QList< int >::iterator i = std::lower_bound( m_sortSizes.begin(), m_sortSizes.end(), size );
             m_sortSizes.insert( i, size );
             const int index = m_sortSizes.count() - m_sortSizes.indexOf( size ) - 1;
@@ -408,12 +408,12 @@ void CoverFoundDialog::saveAs()
     dlg.setAcceptMode( QFileDialog::AcceptSave );
 
     QUrl selectedUrl;
-    selectedUrl.setPath( "cover.jpg" );
+    selectedUrl.setPath( QStringLiteral("cover.jpg") );
     dlg.selectUrl( selectedUrl );
 
     QStringList supportedMimeTypes;
-    supportedMimeTypes << "image/jpeg";
-    supportedMimeTypes << "image/png";
+    supportedMimeTypes << QStringLiteral("image/jpeg");
+    supportedMimeTypes << QStringLiteral("image/png");
     dlg.setMimeTypeFilters( supportedMimeTypes );
 
     QUrl saveUrl;
@@ -440,9 +440,9 @@ void CoverFoundDialog::saveAs()
     QMimeDatabase db;
     const QString &ext = db.suffixForFileName( saveUrl.path() ).toLower();
     bool ok;
-    if( ext == "jpg" || ext == "jpeg" )
+    if( ext == QStringLiteral("jpg") || ext == QStringLiteral("jpeg") )
         ok = image.save( &saveFile, "JPG" );
-    else if( ext == "png" )
+    else if( ext == QStringLiteral("png") )
         ok = image.save( &saveFile, "PNG" );
     else
         ok = image.save( &saveFile );
@@ -525,7 +525,7 @@ bool CoverFoundDialog::fetchBigPix()
 {
     DEBUG_BLOCK
     CoverFoundItem *item = static_cast< CoverFoundItem* >( m_view->currentItem() );
-    const QUrl url( item->metadata().value( "normalarturl" ) );
+    const QUrl url( item->metadata().value( QStringLiteral("normalarturl") ) );
     if( !url.isValid() )
         return false;
 
@@ -613,7 +613,7 @@ void CoverFoundDialog::processQuery( const QString &input )
 
 void CoverFoundDialog::selectDiscogs()
 {
-    KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     config.writeEntry( "Interactive Image Source", "Discogs" );
     m_sortAction->setEnabled( true );
     m_queryPage = 0;
@@ -623,7 +623,7 @@ void CoverFoundDialog::selectDiscogs()
 
 void CoverFoundDialog::selectLastFm()
 {
-    KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     config.writeEntry( "Interactive Image Source", "LastFm" );
     m_sortAction->setEnabled( false );
     m_queryPage = 0;
@@ -633,7 +633,7 @@ void CoverFoundDialog::selectLastFm()
 
 void CoverFoundDialog::selectGoogle()
 {
-    KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     config.writeEntry( "Interactive Image Source", "Google" );
     m_sortAction->setEnabled( true );
     m_queryPage = 0;
@@ -648,7 +648,7 @@ void CoverFoundDialog::setQueryPage( int page )
 
 void CoverFoundDialog::sortingTriggered( bool checked )
 {
-    KConfigGroup config = Amarok::config( "Cover Fetcher" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Cover Fetcher") );
     config.writeEntry( "Sort by Size", checked );
     m_sortEnabled = checked;
     m_isSorted = false;
@@ -662,15 +662,15 @@ void CoverFoundDialog::sortCoversBySize()
     DEBUG_BLOCK
 
     m_sortSizes.clear();
-    QList< QListWidgetItem* > viewItems = m_view->findItems( QChar('*'), Qt::MatchWildcard );
+    QList< QListWidgetItem* > viewItems = m_view->findItems( QStringLiteral("*"), Qt::MatchWildcard );
     QMultiMap<int, CoverFoundItem*> sortItems;
 
     // get a list of cover items sorted (automatically by qmap) by size
-    foreach( QListWidgetItem *viewItem, viewItems  )
+    for( QListWidgetItem *viewItem : viewItems  )
     {
         CoverFoundItem *coverItem = dynamic_cast<CoverFoundItem*>( viewItem );
         const CoverFetch::Metadata &meta = coverItem->metadata();
-        const int itemSize = meta.value( "width" ).toInt() * meta.value( "height" ).toInt();
+        const int itemSize = meta.value( QStringLiteral("width") ).toInt() * meta.value( QStringLiteral("height") ).toInt();
         sortItems.insert( itemSize, coverItem );
         m_sortSizes << itemSize;
     }
@@ -688,7 +688,7 @@ void CoverFoundDialog::sortCoversBySize()
     }
 
     // add the items back to the view in descending order
-    foreach( CoverFoundItem* item, tempItems )
+    for( CoverFoundItem* item : tempItems )
         m_view->insertItem( 0, item );
 
     m_isSorted = true;
@@ -777,9 +777,9 @@ void CoverFoundSideBar::setPixmap( const QPixmap &pixmap )
 void CoverFoundSideBar::updateNotes()
 {
     bool enableNotes( false );
-    if( m_metadata.contains( "notes" ) )
+    if( m_metadata.contains( QStringLiteral("notes") ) )
     {
-        const QString notes = m_metadata.value( "notes" );
+        const QString notes = m_metadata.value( QStringLiteral("notes") );
         if( !notes.isEmpty() )
         {
             m_notes->setText( notes );
@@ -839,14 +839,14 @@ void CoverFoundSideBar::updateMetaTable()
 
     QString refUrl;
 
-    const QString source = m_metadata.value( "source" );
-    if( source == "Last.fm" || source == "Discogs" )
+    const QString source = m_metadata.value( QStringLiteral("source") );
+    if( source == QStringLiteral("Last.fm") || source == QStringLiteral("Discogs") )
     {
-        refUrl = m_metadata.value( "releaseurl" );
+        refUrl = m_metadata.value( QStringLiteral("releaseurl") );
     }
-    else if( source == "Google" )
+    else if( source == QStringLiteral("Google") )
     {
-        refUrl = m_metadata.value( "imgrefurl" );
+        refUrl = m_metadata.value( QStringLiteral("imgrefurl") );
     }
 
     if( !refUrl.isEmpty() )
@@ -856,7 +856,7 @@ void CoverFoundSideBar::updateMetaTable()
         const QString &toolUrl = refUrl;
         const QString &tooltip = qfm.elidedText( toolUrl, Qt::ElideMiddle, 350 );
         const QString &decoded = QUrl::fromPercentEncoding( refUrl.toLocal8Bit() );
-        const QString &url     = QString( "<a href=\"%1\">%2</a>" )
+        const QString &url     = QStringLiteral( "<a href=\"%1\">%2</a>" )
                                     .arg( decoded,
                                           i18nc("@item::intable URL", "link") );
 
@@ -864,7 +864,7 @@ void CoverFoundSideBar::updateMetaTable()
         label->setOpenExternalLinks( true );
         label->setTextInteractionFlags( Qt::TextBrowserInteraction );
         label->setToolTip( tooltip );
-        layout->addRow( QString( "<b>%1:</b>" ).arg( i18nc("@item::intable", "URL") ), label );
+        layout->addRow( QStringLiteral( "<b>%1:</b>" ).arg( i18nc("@item::intable", "URL") ), label );
     }
 }
 
@@ -928,7 +928,7 @@ void CoverFoundItem::setCaption()
     const QString &width = m_metadata.value( QLatin1String("width") );
     const QString &height = m_metadata.value( QLatin1String("height") );
     if( !width.isEmpty() && !height.isEmpty() )
-        captions << QString( "%1 x %2" ).arg( width, height );
+        captions << QStringLiteral( "%1 x %2" ).arg( width, height );
 
     int size = m_metadata.value( QLatin1String("size") ).toInt();
     if( size )
