@@ -38,6 +38,7 @@
 #include "widgets/PixmapViewer.h"
 
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
 #include <QDialogButtonBox>
 #include <QMenu>    //showCoverMenu()
@@ -48,7 +49,6 @@
 #include <QStatusBar>
 #include <QStringList>
 #include <QTimer>    //search filter timer
-#include <QToolButton>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 #include <QVBoxLayout>
@@ -97,7 +97,7 @@ CoverManager::CoverManager( QWidget *parent )
 {
     DEBUG_BLOCK
 
-    setObjectName( "TheCoverManager" );
+    setObjectName( QStringLiteral("TheCoverManager") );
 
     s_instance = this;
 
@@ -132,7 +132,7 @@ CoverManager::CoverManager( QWidget *parent )
 
     ArtistItem *item = nullptr;
     item = new ArtistItem( i18n( "All Artists" ) );
-    item->setIcon(0, QIcon::fromTheme( "media-optical-audio-amarok" ) );
+    item->setIcon(0, QIcon::fromTheme( QStringLiteral("media-optical-audio-amarok") ) );
     m_items.append( item );
 
     Collections::Collection *coll = CollectionManager::instance()->primaryCollection();
@@ -154,7 +154,7 @@ void
 CoverManager::slotArtistQueryResult( Meta::ArtistList artists ) //SLOT
 {
     DEBUG_BLOCK
-    foreach( Meta::ArtistPtr artist, artists )
+    for( Meta::ArtistPtr artist : artists )
         m_artistList << artist;
 }
 
@@ -162,10 +162,10 @@ void
 CoverManager::slotContinueConstruction() //SLOT
 {
     DEBUG_BLOCK
-    foreach( Meta::ArtistPtr artist, m_artistList )
+    for( Meta::ArtistPtr artist : m_artistList )
     {
         ArtistItem* item = new ArtistItem( m_artistView, artist );
-        item->setIcon( 0, QIcon::fromTheme( "view-media-artist-amarok" ) );
+        item->setIcon( 0, QIcon::fromTheme( QStringLiteral("view-media-artist-amarok") ) );
         m_items.append( item );
     }
     m_artistView->insertTopLevelItems( 0, m_items );
@@ -205,7 +205,7 @@ CoverManager::slotContinueConstruction() //SLOT
     connect( m_viewMenu, &QMenu::triggered, this, &CoverManager::slotAlbumFilterTriggered );
 
     //fetch missing covers button
-    m_fetchButton = new QPushButton( QIcon( "get-hot-new-stuff-amarok" ), i18n("Fetch Missing Covers"), hbox );
+    m_fetchButton = new QPushButton( QIcon::fromTheme( QStringLiteral("get-hot-new-stuff-amarok") ), i18n("Fetch Missing Covers"), hbox );
     connect( m_fetchButton, &QAbstractButton::clicked, this, &CoverManager::fetchMissingCovers );
 
     m_selectAllAlbums->setChecked( true );
@@ -229,7 +229,7 @@ CoverManager::slotContinueConstruction() //SLOT
     connect( m_progress, &CompoundProgressBar::allDone, this, &CoverManager::progressAllDone );
 
     QSize size = this->screen()->size() / 1.5;
-    QSize sz = Amarok::config( "Cover Manager" ).readEntry( "Window Size", size );
+    QSize sz = Amarok::config( QStringLiteral("Cover Manager") ).readEntry( "Window Size", size );
     resize( sz.width(), sz.height() );
 
     m_splitter->setStretchFactor( m_splitter->indexOf( m_artistView ), 1 );
@@ -269,7 +269,7 @@ CoverManager::slotContinueConstruction() //SLOT
 
 CoverManager::~CoverManager()
 {
-    Amarok::config( "Cover Manager" ).writeEntry( "Window Size", size() );
+    Amarok::config( QStringLiteral("Cover Manager") ).writeEntry( "Window Size", size() );
     qDeleteAll( m_coverItems );
     delete m_coverView;
     m_coverView = nullptr;
@@ -288,7 +288,7 @@ void
 CoverManager::metadataChanged(const Meta::AlbumPtr &album )
 {
     const QString albumName = album->name();
-    foreach( CoverViewItem *item, m_coverItems )
+    for( CoverViewItem *item : m_coverItems )
     {
         if( albumName == item->albumPtr()->name() )
             item->loadCover();
@@ -308,7 +308,7 @@ CoverManager::fetchMissingCovers() //SLOT
             m_fetchCovers += coverItem->albumPtr();
     }
 
-    debug() << QString( "Fetching %1 missing covers" ).arg( m_fetchCovers.size() );
+    debug() << QStringLiteral( "Fetching %1 missing covers" ).arg( m_fetchCovers.size() );
 
     ProgressBar *fetchProgressBar = new ProgressBar( this );
     fetchProgressBar->setDescription( i18n( "Fetching" ) );
@@ -361,7 +361,7 @@ CoverManager::slotArtistSelected() //SLOT
 
     qm->beginOr();
     const QList< QTreeWidgetItem* > items = m_artistView->selectedItems();
-    foreach( const QTreeWidgetItem *item, items )
+    for( const QTreeWidgetItem *item : items )
     {
         const ArtistItem *artistItem = static_cast< const ArtistItem* >( item );
         if( artistItem != m_artistView->invisibleRootItem()->child( 0 ) )
@@ -422,7 +422,7 @@ CoverManager::slotArtistQueryDone() //SLOT
     //also provides quite a massive speed improvement when loading covers.
     m_coverView->hide();
     m_coverViewSpacer->show();
-    foreach( const Meta::AlbumPtr &album, m_albumList )
+    for( const Meta::AlbumPtr &album : m_albumList )
     {
         qApp->processEvents( QEventLoop::ExcludeSocketNotifiers );
         if( isHidden() )
@@ -497,7 +497,7 @@ CoverManager::slotSetFilter() //SLOT
         item = tmp;
     }
 
-    foreach( QListWidgetItem *item, m_coverItems )
+    for( QListWidgetItem *item : m_coverItems )
     {
         CoverViewItem *coverItem = static_cast<CoverViewItem*>(item);
         if( coverItem->album().contains( m_filter, Qt::CaseInsensitive ) || coverItem->artist().contains( m_filter, Qt::CaseInsensitive ) )
@@ -530,7 +530,7 @@ CoverManager::changeView( CoverManager::View id, bool force ) //SLOT
     while( itemsCount-- > 0 )
        m_coverView->takeItem( 0 );
 
-    foreach( QListWidgetItem *item, m_coverItems )
+    for( QListWidgetItem *item : m_coverItems )
     {
         bool show = false;
         CoverViewItem *coverItem = static_cast<CoverViewItem*>(item);
@@ -588,7 +588,7 @@ CoverManager::stopFetching()
 void
 CoverManager::loadCover( const QString &artist, const QString &album )
 {
-    foreach( QListWidgetItem *item, m_coverItems )
+    for( QListWidgetItem *item : m_coverItems )
     {
         CoverViewItem *coverItem = static_cast<CoverViewItem*>(item);
         if ( album == coverItem->album() && ( artist == coverItem->artist() || ( artist.isEmpty() && coverItem->artist().isEmpty() ) ) )
@@ -633,7 +633,7 @@ CoverManager::updateStatusBar()
 
         if( m_fetchCovers.size() == 1 )
         {
-            foreach( Meta::AlbumPtr album, m_fetchCovers )
+            for( Meta::AlbumPtr album : m_fetchCovers )
             {
                 if( album->hasAlbumArtist() && !album->albumArtist()->prettyName().isEmpty() )
                 {
@@ -692,7 +692,7 @@ CoverManager::updateStatusBar()
             if( selected.first() != m_artistView->invisibleRootItem()->child( 0 ) )
             {
                 QStringList artists;
-                foreach( const QTreeWidgetItem *item, selected )
+                for( const QTreeWidgetItem *item : selected )
                 {
                     QString artist = item->text( 0 );
                     Amarok::manipulateThe( artist, false );
@@ -709,7 +709,7 @@ CoverManager::updateStatusBar()
         m_fetchButton->setEnabled( missingCounter );
     }
 
-    m_statusLabel->setText( text );
+    QTimer::singleShot( 0, this, [=]() { setStatusText( text ); } );
 }
 
 void
@@ -724,7 +724,6 @@ CoverManager::delayedDestruct()
 void
 CoverManager::setStatusText( const QString &text )
 {
-    m_oldStatusText = m_statusLabel->text();
     m_statusLabel->setText( text );
 }
 
@@ -737,7 +736,7 @@ CoverView::CoverView( QWidget *parent, const char *name, Qt::WindowFlags f )
 {
     DEBUG_BLOCK
 
-    setObjectName( name );
+    setObjectName( QLatin1String(name) );
     setWindowFlags( f );
     setViewMode( QListView::IconMode );
     setMovement( QListView::Static );
@@ -776,7 +775,7 @@ CoverView::contextMenuEvent( QContextMenuEvent *event )
             if( ac )
             {
                 actions = ac->actions();
-                foreach( QAction *action, actions )
+                for( QAction *action : actions )
                     menu.addAction( action );
             }
         }
@@ -790,7 +789,7 @@ CoverView::contextMenuEvent( QContextMenuEvent *event )
         Meta::AlbumList unsetAlbums;
         Meta::AlbumList fetchAlbums;
 
-        foreach( QListWidgetItem *item, items )
+        for( QListWidgetItem *item : items )
         {
             CoverViewItem *cvItem = dynamic_cast<CoverViewItem*>(item);
             Meta::AlbumPtr album = cvItem->albumPtr();
@@ -800,7 +799,7 @@ CoverView::contextMenuEvent( QContextMenuEvent *event )
                 if( ac )
                 {
                     QList<QAction *> actions = ac->actions();
-                    foreach( QAction *action, actions )
+                    for( QAction *action : actions )
                     {
                         if( qobject_cast<FetchCoverAction*>(action) )
                             fetchAlbums << album;
