@@ -21,13 +21,11 @@
 #include "core/meta/Observer.h"
 #include "covermanager/CoverFetcher.h"
 
+#include <QAction>
 #include <QDialog>
-
-#include <QDropEvent>
 #include <QLabel>
 #include <QListWidget>
 #include <QListWidgetItem>
-#include <QAction>
 
 namespace Amarok { class LineEdit; }
 
@@ -127,7 +125,6 @@ class CoverManager : public QDialog, public Meta::Observer
         //status bar widgets
         CompoundProgressBar *m_progress;
         KSqueezedTextLabel *m_statusLabel;
-        QString         m_oldStatusText;
 
         QTimer         *m_timer;              //search filter timer
         QList<CoverViewItem*> m_coverItems; //used for filtering
