@@ -24,7 +24,6 @@
 #include "GpodderServiceSettings.h"
 #include "GpodderTagTreeItem.h"
 
-#include <QEventLoop>
 #include <QList>
 #include <QNetworkConfigurationManager>
 #include <QTimer>
@@ -46,15 +45,15 @@ GpodderServiceModel::GpodderServiceModel( ApiRequest *request, QObject *parent )
     
     m_rootItem = new GpodderTreeItem( );
 
-    m_topTagsItem = new GpodderTreeItem( m_rootItem, "Top Tags" );
+    m_topTagsItem = new GpodderTreeItem( m_rootItem, QStringLiteral("Top Tags") );
     m_rootItem->appendChild( m_topTagsItem );
 
-    m_topPodcastsItem = new GpodderTreeItem( m_rootItem, "Top Podcasts" );
+    m_topPodcastsItem = new GpodderTreeItem( m_rootItem, QStringLiteral("Top Podcasts") );
     m_rootItem->appendChild( m_topPodcastsItem );
 
     if ( config.isDataLoaded() && config.enableProvider() )
     {
-        m_suggestedPodcastsItem = new GpodderTreeItem( m_rootItem, "Suggested Podcasts" );
+        m_suggestedPodcastsItem = new GpodderTreeItem( m_rootItem, QStringLiteral("Suggested Podcasts") );
         m_rootItem->appendChild( m_suggestedPodcastsItem );
 
     }
@@ -233,7 +232,7 @@ GpodderServiceModel::insertPodcastList( mygpo::PodcastListPtr podcasts,
 {
     DEBUG_BLOCK
 
-    emit layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
     beginInsertRows( parentItem, 0, podcasts->list().count() - 1 );
     GpodderTreeItem *item = static_cast<GpodderTreeItem*>( parentItem.internalPointer() );
     if( item != nullptr )
@@ -243,7 +242,7 @@ GpodderServiceModel::insertPodcastList( mygpo::PodcastListPtr podcasts,
     }
     endInsertRows();
 
-    emit layoutChanged();
+    Q_EMIT layoutChanged();
 }
 
 bool
