@@ -87,7 +87,11 @@ AnimatedLabelStack::ensureAnimationStatus()
 }
 
 void
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 AnimatedLabelStack::enterEvent( QEvent * )
+#else
+AnimatedLabelStack::enterEvent( QEnterEvent * )
+#endif
 {
     // wait a short time, then pulse through entries
     m_explicit = false;
@@ -196,7 +200,7 @@ AnimatedLabelStack::elidedText( const QString& text ) const
 
     // Insert a whitespace between text and "..." (looks nicer)
     if( newText != text )
-        newText.insert( newText.length() -1, ' ' );
+        newText.insert( newText.length() -1, QLatin1Char(' ') );
 
 
     return newText;
