@@ -49,7 +49,7 @@ private Q_SLOTS:
 private:
     Collections::SqlCollection *m_collection;
     QSharedPointer<MySqlEmbeddedStorage> m_storage;
-    QTemporaryDir *m_tmpDir;
+    static QTemporaryDir *s_tmpDir;
 };
 
 #endif // TEST_DATABASEUPDATER_H
